@@ -1,5 +1,5 @@
 /*
- *  Copyright (c) 2006           Ji YongGang <jungle@soforge-studio.com>
+ *  Copyright (C) 2010 Ji YongGang <jungleji@gmail.com>
  *
  *  ChmSee is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -28,11 +28,11 @@
  ***************************************************************************/
 
 #include "config.h"
-#include "startup.h"
 
 #include <gtk/gtk.h>
 
-#include "utils/utils.h"
+#include "startup.h"
+#include "utils.h"
 
 static void
 startup_popup_cb(gpointer data)
@@ -51,7 +51,7 @@ startup_popup_new(void)
         /* following code stolen from StarDict <http://stardict.sourceforge.net> */
         gtk_window_set_auto_startup_notification(FALSE);
 
-        pixbuf = gdk_pixbuf_new_from_file(get_resource_path("chmsee-splash.png"), NULL);
+        pixbuf = gdk_pixbuf_new_from_file(RESOURCE_FILE ("chmsee-splash.png"), NULL);
 
         w = gdk_pixbuf_get_width(pixbuf);
         h = gdk_pixbuf_get_height(pixbuf);
