@@ -1,5 +1,6 @@
 /*
- *  Copyright (c) 2006           Ji YongGang <jungle@soforge-studio.com>
+ *  Copyright (C) 2010 Ji YongGang <jungleji@gmail.com>
+ *  Copyright (C) 2009 LI Daobing <lidaobing@gmail.com>
  *
  *  ChmSee is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,19 +18,13 @@
  *  Boston, MA 02110-1301, USA.
  */
 
-#ifndef __UTILS_H__
-#define __UTILS_H__
+#ifndef __CS_UTILS_H__
+#define __CS_UTILS_H__
 
+#include <stdio.h>
 #include <glib.h>
 
-#include "chmsee.h"
-#include "chmfile.h"
-
-#ifdef _DEBUG
-#define d(x) x
-#else
-#define d(x)
-#endif
+G_BEGIN_DECLS
 
 #ifdef ENABLE_NLS
 #  include <libintl.h>
@@ -50,19 +45,20 @@
 #  define N_(String) (String)
 #endif
 
+#define MAXLINE 1024
+#define ENTRY_MAX_LENGTH 80
+
+#define RESOURCE_FILE(file) (CHMSEE_DATA_DIR G_DIR_SEPARATOR_S file)
+#define BUILDER_WIDGET(builder, widget) (GTK_WIDGET (gtk_builder_get_object(builder, widget)))
+
 gchar *convert_filename_to_utf8(const gchar *, const gchar *);
 gchar *convert_string_to_utf8(const gchar *, const gchar *);
-gint ncase_compare_utf8_string(const gchar *, const gchar *);
-gchar *file_exist_ncase(const gchar *);
-char *url_decode(const char*);
-void command_delete_tmpdir(char *);
 gchar *get_real_uri(const gchar *);
+char  *uri_decode(const char*);
+gint   ncase_compare_utf8_string(const gchar *, const gchar *);
+void   convert_old_config_file(const gchar *, const gchar *);
+gchar *file_exist_ncase(const gchar *);
 
-void load_chmsee_config(ChmSee *);
-void save_chmsee_config(ChmSee *);
-void load_fileinfo(ChmFile *);
-void save_fileinfo(ChmFile *);
-GList *load_bookmarks(const gchar *);
-void save_bookmarks(const gchar *, GList *);
+G_END_DECLS
 
-#endif /* !__UTILS_H__ */
+#endif /* !__CS_UTILS_H__ */
